@@ -3,6 +3,7 @@ Insight into codes of conduct for your communities.
 """
 
 
+# pylint: disable=too-many-arguments
 class CodesOfConduct:
     """
     Insight into codes of conduct for your communities.
@@ -15,7 +16,7 @@ class CodesOfConduct:
         self._base_url = client._base_url
         self._execute = client._execute
 
-    def get_all_codes_of_conduct(self, payload=None):
+    def get_all_codes_of_conduct(self, params=None, payload=None):
         """
         Get all codes of conduct
         https://docs.github.com/rest/reference/codes-of-conduct#get-all-codes-of-conduct
@@ -26,10 +27,10 @@ class CodesOfConduct:
 
         """
         url = self._base_url + "/codes_of_conduct"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_a_code_of_conduct(self, key, payload=None):
+    def get_a_code_of_conduct(self, key, params=None, payload=None):
         """
         Get a code of conduct
         https://docs.github.com/rest/reference/codes-of-conduct#get-a-code-of-conduct
@@ -40,5 +41,5 @@ class CodesOfConduct:
 
         """
         url = self._base_url + f"/codes_of_conduct/{key}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
