@@ -3,6 +3,7 @@ Administer a GitHub enterprise.
 """
 
 
+# pylint: disable=too-many-arguments
 class EnterpriseAdmin:
     # pylint: disable=too-many-public-methods
     """
@@ -16,7 +17,9 @@ class EnterpriseAdmin:
         self._base_url = client._base_url
         self._execute = client._execute
 
-    def get_github_actions_permissions_for_an_enterprise(self, enterprise, payload=None):
+    def get_github_actions_permissions_for_an_enterprise(
+        self, enterprise, params=None, payload=None
+    ):
         """
         Get GitHub Actions permissions for an enterprise
         https://docs.github.com/rest/reference/actions#get-github-actions-permissions-for-an-enterprise
@@ -27,10 +30,12 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/permissions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def set_github_actions_permissions_for_an_enterprise(self, enterprise, payload=None):
+    def set_github_actions_permissions_for_an_enterprise(
+        self, enterprise, params=None, payload=None
+    ):
         """
         Set GitHub Actions permissions for an enterprise
         https://docs.github.com/rest/reference/actions#set-github-actions-permissions-for-an-enterprise
@@ -41,11 +46,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/permissions"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def list_selected_organizations_enabled_for_github_actions_in_an_enterprise(
-        self, enterprise, payload=None
+        self, enterprise, params=None, payload=None
     ):
         """
         List selected organizations enabled for GitHub Actions in an enterprise
@@ -58,11 +63,11 @@ class EnterpriseAdmin:
          page
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def set_selected_organizations_enabled_for_github_actions_in_an_enterprise(
-        self, enterprise, payload=None
+        self, enterprise, params=None, payload=None
     ):
         """
         Set selected organizations enabled for GitHub Actions in an enterprise
@@ -74,11 +79,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def enable_a_selected_organization_for_github_actions_in_an_enterprise(
-        self, enterprise, org_id, payload=None
+        self, enterprise, org_id, params=None, payload=None
     ):
         """
         Enable a selected organization for GitHub Actions in an enterprise
@@ -93,11 +98,11 @@ class EnterpriseAdmin:
         url = (
             self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations/{org_id}"
         )
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def disable_a_selected_organization_for_github_actions_in_an_enterprise(
-        self, enterprise, org_id, payload=None
+        self, enterprise, org_id, params=None, payload=None
     ):
         """
         Disable a selected organization for GitHub Actions in an enterprise
@@ -112,11 +117,11 @@ class EnterpriseAdmin:
         url = (
             self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations/{org_id}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def get_allowed_actions_and_reusable_workflows_for_an_enterprise(
-        self, enterprise, payload=None
+        self, enterprise, params=None, payload=None
     ):
         """
         Get allowed actions and reusable workflows for an enterprise
@@ -128,11 +133,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/selected-actions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def set_allowed_actions_and_reusable_workflows_for_an_enterprise(
-        self, enterprise, payload=None
+        self, enterprise, params=None, payload=None
     ):
         """
         Set allowed actions and reusable workflows for an enterprise
@@ -144,10 +149,12 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/selected-actions"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def list_self_hosted_runner_groups_for_an_enterprise(self, enterprise, payload=None):
+    def list_self_hosted_runner_groups_for_an_enterprise(
+        self, enterprise, params=None, payload=None
+    ):
         """
         List self-hosted runner groups for an enterprise
         https://docs.github.com/rest/reference/actions#list-self-hosted-runner-groups-for-an-enterprise
@@ -160,10 +167,12 @@ class EnterpriseAdmin:
          visible-to-organization
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_a_self_hosted_runner_group_for_an_enterprise(self, enterprise, payload=None):
+    def create_a_self_hosted_runner_group_for_an_enterprise(
+        self, enterprise, params=None, payload=None
+    ):
         """
         Create a self-hosted runner group for an enterprise
         https://docs.github.com/rest/reference/actions#create-self-hosted-runner-group-for-an-enterprise
@@ -174,11 +183,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def get_a_self_hosted_runner_group_for_an_enterprise(
-        self, enterprise, runner_group_id, payload=None
+        self, enterprise, runner_group_id, params=None, payload=None
     ):
         """
         Get a self-hosted runner group for an enterprise
@@ -191,11 +200,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def update_a_self_hosted_runner_group_for_an_enterprise(
-        self, enterprise, runner_group_id, payload=None
+        self, enterprise, runner_group_id, params=None, payload=None
     ):
         """
         Update a self-hosted runner group for an enterprise
@@ -208,11 +217,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
     def delete_a_self_hosted_runner_group_from_an_enterprise(
-        self, enterprise, runner_group_id, payload=None
+        self, enterprise, runner_group_id, params=None, payload=None
     ):
         """
         Delete a self-hosted runner group from an enterprise
@@ -225,11 +234,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def list_organization_access_to_a_self_hosted_runner_group_in_an_enterprise(
-        self, enterprise, runner_group_id, payload=None
+        self, enterprise, runner_group_id, params=None, payload=None
     ):
         """
         List organization access to a self-hosted runner group in an enterprise
@@ -246,11 +255,11 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations"
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def set_organization_access_for_a_self_hosted_runner_group_in_an_enterprise(
-        self, enterprise, runner_group_id, payload=None
+        self, enterprise, runner_group_id, params=None, payload=None
     ):
         """
         Set organization access for a self-hosted runner group in an enterprise
@@ -266,11 +275,11 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations"
         )
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def add_organization_access_to_a_self_hosted_runner_group_in_an_enterprise(
-        self, enterprise, runner_group_id, org_id, payload=None
+        self, enterprise, runner_group_id, org_id, params=None, payload=None
     ):
         """
         Add organization access to a self-hosted runner group in an enterprise
@@ -287,11 +296,11 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations/{org_id}"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def remove_organization_access_to_a_self_hosted_runner_group_in_an_enterprise(
-        self, enterprise, runner_group_id, org_id, payload=None
+        self, enterprise, runner_group_id, org_id, params=None, payload=None
     ):
         """
         Remove organization access to a self-hosted runner group in an enterprise
@@ -308,11 +317,11 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations/{org_id}"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def list_self_hosted_runners_in_a_group_for_an_enterprise(
-        self, enterprise, runner_group_id, payload=None
+        self, enterprise, runner_group_id, params=None, payload=None
     ):
         """
         List self-hosted runners in a group for an enterprise
@@ -329,11 +338,11 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners"
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def set_self_hosted_runners_in_a_group_for_an_enterprise(
-        self, enterprise, runner_group_id, payload=None
+        self, enterprise, runner_group_id, params=None, payload=None
     ):
         """
         Set self-hosted runners in a group for an enterprise
@@ -349,11 +358,11 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners"
         )
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def add_a_self_hosted_runner_to_a_group_for_an_enterprise(
-        self, enterprise, runner_group_id, runner_id, payload=None
+        self, enterprise, runner_group_id, runner_id, params=None, payload=None
     ):
         """
         Add a self-hosted runner to a group for an enterprise
@@ -370,11 +379,11 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners/{runner_id}"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def remove_a_self_hosted_runner_from_a_group_for_an_enterprise(
-        self, enterprise, runner_group_id, runner_id, payload=None
+        self, enterprise, runner_group_id, runner_id, params=None, payload=None
     ):
         """
         Remove a self-hosted runner from a group for an enterprise
@@ -391,10 +400,10 @@ class EnterpriseAdmin:
             self._base_url
             + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners/{runner_id}"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_self_hosted_runners_for_an_enterprise(self, enterprise, payload=None):
+    def list_self_hosted_runners_for_an_enterprise(self, enterprise, params=None, payload=None):
         """
         List self-hosted runners for an enterprise
         https://docs.github.com/rest/reference/actions#list-self-hosted-runners-for-an-enterprise
@@ -406,10 +415,10 @@ class EnterpriseAdmin:
          page
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_runner_applications_for_an_enterprise(self, enterprise, payload=None):
+    def list_runner_applications_for_an_enterprise(self, enterprise, params=None, payload=None):
         """
         List runner applications for an enterprise
         https://docs.github.com/rest/reference/actions#list-runner-applications-for-an-enterprise
@@ -420,10 +429,10 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/downloads"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_a_registration_token_for_an_enterprise(self, enterprise, payload=None):
+    def create_a_registration_token_for_an_enterprise(self, enterprise, params=None, payload=None):
         """
         Create a registration token for an enterprise
         https://docs.github.com/rest/reference/actions#create-a-registration-token-for-an-enterprise
@@ -434,10 +443,10 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/registration-token"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def create_a_remove_token_for_an_enterprise(self, enterprise, payload=None):
+    def create_a_remove_token_for_an_enterprise(self, enterprise, params=None, payload=None):
         """
         Create a remove token for an enterprise
         https://docs.github.com/rest/reference/actions#create-a-remove-token-for-an-enterprise
@@ -448,10 +457,12 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/remove-token"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_a_self_hosted_runner_for_an_enterprise(self, enterprise, runner_id, payload=None):
+    def get_a_self_hosted_runner_for_an_enterprise(
+        self, enterprise, runner_id, params=None, payload=None
+    ):
         """
         Get a self-hosted runner for an enterprise
         https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-for-an-enterprise
@@ -463,10 +474,12 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def delete_a_self_hosted_runner_from_an_enterprise(self, enterprise, runner_id, payload=None):
+    def delete_a_self_hosted_runner_from_an_enterprise(
+        self, enterprise, runner_id, params=None, payload=None
+    ):
         """
         Delete a self-hosted runner from an enterprise
         https://docs.github.com/rest/reference/actions#delete-self-hosted-runner-from-an-enterprise
@@ -478,11 +491,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def list_labels_for_a_self_hosted_runner_for_an_enterprise(
-        self, enterprise, runner_id, payload=None
+        self, enterprise, runner_id, params=None, payload=None
     ):
         """
         List labels for a self-hosted runner for an enterprise
@@ -495,11 +508,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def add_custom_labels_to_a_self_hosted_runner_for_an_enterprise(
-        self, enterprise, runner_id, payload=None
+        self, enterprise, runner_id, params=None, payload=None
     ):
         """
         Add custom labels to a self-hosted runner for an enterprise
@@ -512,11 +525,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def set_custom_labels_for_a_self_hosted_runner_for_an_enterprise(
-        self, enterprise, runner_id, payload=None
+        self, enterprise, runner_id, params=None, payload=None
     ):
         """
         Set custom labels for a self-hosted runner for an enterprise
@@ -529,11 +542,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def remove_all_custom_labels_from_a_self_hosted_runner_for_an_enterprise(
-        self, enterprise, runner_id, payload=None
+        self, enterprise, runner_id, params=None, payload=None
     ):
         """
         Remove all custom labels from a self-hosted runner for an enterprise
@@ -546,11 +559,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def remove_a_custom_label_from_a_self_hosted_runner_for_an_enterprise(
-        self, enterprise, runner_id, name, payload=None
+        self, enterprise, runner_id, name, params=None, payload=None
     ):
         """
         Remove a custom label from a self-hosted runner for an enterprise
@@ -566,10 +579,10 @@ class EnterpriseAdmin:
         url = (
             self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels/{name}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def get_the_audit_log_for_an_enterprise(self, enterprise, payload=None):
+    def get_the_audit_log_for_an_enterprise(self, enterprise, params=None, payload=None):
         """
         Get the audit log for an enterprise
         https://docs.github.com/rest/reference/enterprise-admin#get-the-audit-log-for-an-enterprise
@@ -586,10 +599,12 @@ class EnterpriseAdmin:
          per-page
         """
         url = self._base_url + f"/enterprises/{enterprise}/audit-log"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def retrieve_enterprise_license_sync_consumed_licenses(self, enterprise, payload=None):
+    def retrieve_enterprise_license_sync_consumed_licenses(
+        self, enterprise, params=None, payload=None
+    ):
         """
         Retrieve Enterprise License Sync Consumed Licenses
         https://docs.github.com/rest/reference/enterprise-admin#retrieve-enterprise-license-sync-consumed-licenses
@@ -601,10 +616,12 @@ class EnterpriseAdmin:
          page
         """
         url = self._base_url + f"/enterprises/{enterprise}/consumed-licenses"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def provides_license_sync_job_status_for_connected_instances(self, enterprise, payload=None):
+    def provides_license_sync_job_status_for_connected_instances(
+        self, enterprise, params=None, payload=None
+    ):
         """
         Provides License Sync Job status for connected instances
         https://docs.github.com/rest/reference/enterprise-admin#provides-license-sync-job-status-for-connected-instances
@@ -615,10 +632,10 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/enterprises/{enterprise}/license-sync-status"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_provisioned_scim_groups_for_an_enterprise(self, enterprise, payload=None):
+    def list_provisioned_scim_groups_for_an_enterprise(self, enterprise, params=None, payload=None):
         """
         List provisioned SCIM groups for an enterprise
         https://docs.github.com/rest/reference/enterprise-admin#list-provisioned-scim-groups-for-an-enterprise
@@ -632,10 +649,12 @@ class EnterpriseAdmin:
          excludedAttributes
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def provision_a_scim_enterprise_group_and_invite_users(self, enterprise, payload=None):
+    def provision_a_scim_enterprise_group_and_invite_users(
+        self, enterprise, params=None, payload=None
+    ):
         """
         Provision a SCIM enterprise group and invite users
         https://docs.github.com/rest/reference/enterprise-admin#provision-a-scim-enterprise-group-and-invite-users
@@ -646,11 +665,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def get_scim_provisioning_information_for_an_enterprise_group(
-        self, enterprise, scim_group_id, payload=None
+        self, enterprise, scim_group_id, params=None, payload=None
     ):
         """
         Get SCIM provisioning information for an enterprise group
@@ -663,11 +682,11 @@ class EnterpriseAdmin:
         excludedAttributes
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def set_scim_information_for_a_provisioned_enterprise_group(
-        self, enterprise, scim_group_id, payload=None
+        self, enterprise, scim_group_id, params=None, payload=None
     ):
         """
         Set SCIM information for a provisioned enterprise group
@@ -680,11 +699,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def update_an_attribute_for_a_scim_enterprise_group(
-        self, enterprise, scim_group_id, payload=None
+        self, enterprise, scim_group_id, params=None, payload=None
     ):
         """
         Update an attribute for a SCIM enterprise group
@@ -697,10 +716,12 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def delete_a_scim_group_from_an_enterprise(self, enterprise, scim_group_id, payload=None):
+    def delete_a_scim_group_from_an_enterprise(
+        self, enterprise, scim_group_id, params=None, payload=None
+    ):
         """
         Delete a SCIM group from an enterprise
         https://docs.github.com/rest/reference/enterprise-admin#delete-a-scim-group-from-an-enterprise
@@ -712,10 +733,12 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_scim_provisioned_identities_for_an_enterprise(self, enterprise, payload=None):
+    def list_scim_provisioned_identities_for_an_enterprise(
+        self, enterprise, params=None, payload=None
+    ):
         """
         List SCIM provisioned identities for an enterprise
         https://docs.github.com/rest/reference/enterprise-admin#list-scim-provisioned-identities-for-an-enterprise
@@ -728,10 +751,10 @@ class EnterpriseAdmin:
          filter
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def provision_and_invite_a_scim_enterprise_user(self, enterprise, payload=None):
+    def provision_and_invite_a_scim_enterprise_user(self, enterprise, params=None, payload=None):
         """
         Provision and invite a SCIM enterprise user
         https://docs.github.com/rest/reference/enterprise-admin#provision-and-invite-a-scim-enterprise-user
@@ -742,11 +765,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def get_scim_provisioning_information_for_an_enterprise_user(
-        self, enterprise, scim_user_id, payload=None
+        self, enterprise, scim_user_id, params=None, payload=None
     ):
         """
         Get SCIM provisioning information for an enterprise user
@@ -759,11 +782,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def set_scim_information_for_a_provisioned_enterprise_user(
-        self, enterprise, scim_user_id, payload=None
+        self, enterprise, scim_user_id, params=None, payload=None
     ):
         """
         Set SCIM information for a provisioned enterprise user
@@ -776,11 +799,11 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def update_an_attribute_for_a_scim_enterprise_user(
-        self, enterprise, scim_user_id, payload=None
+        self, enterprise, scim_user_id, params=None, payload=None
     ):
         """
         Update an attribute for a SCIM enterprise user
@@ -793,10 +816,12 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def delete_a_scim_user_from_an_enterprise(self, enterprise, scim_user_id, payload=None):
+    def delete_a_scim_user_from_an_enterprise(
+        self, enterprise, scim_user_id, params=None, payload=None
+    ):
         """
         Delete a SCIM user from an enterprise
         https://docs.github.com/rest/reference/enterprise-admin#delete-a-scim-user-from-an-enterprise
@@ -808,5 +833,5 @@ class EnterpriseAdmin:
 
         """
         url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
