@@ -3,6 +3,7 @@ Interact with GitHub Issues.
 """
 
 
+# pylint: disable=too-many-arguments
 class Issues:
     # pylint: disable=too-many-public-methods
     """
@@ -16,7 +17,7 @@ class Issues:
         self._base_url = client._base_url
         self._execute = client._execute
 
-    def list_issues_assigned_to_the_authenticated_user(self, payload=None):
+    def list_issues_assigned_to_the_authenticated_user(self, params=None, payload=None):
         """
         List issues assigned to the authenticated user
         https://docs.github.com/rest/reference/issues#list-issues-assigned-to-the-authenticated-user
@@ -38,10 +39,12 @@ class Issues:
          page
         """
         url = self._base_url + "/issues"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_organization_issues_assigned_to_the_authenticated_user(self, org, payload=None):
+    def list_organization_issues_assigned_to_the_authenticated_user(
+        self, org, params=None, payload=None
+    ):
         """
         List organization issues assigned to the authenticated user
         https://docs.github.com/rest/reference/issues#list-organization-issues-assigned-to-the-authenticated-user
@@ -59,10 +62,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/orgs/{org}/issues"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_assignees(self, owner, repo, payload=None):
+    def list_assignees(self, owner, repo, params=None, payload=None):
         """
         List assignees
         https://docs.github.com/rest/reference/issues#list-assignees
@@ -75,10 +78,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/assignees"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def check_if_a_user_can_be_assigned(self, owner, repo, assignee, payload=None):
+    def check_if_a_user_can_be_assigned(self, owner, repo, assignee, params=None, payload=None):
         """
         Check if a user can be assigned
         https://docs.github.com/rest/reference/issues#check-if-a-user-can-be-assigned
@@ -91,10 +94,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/assignees/{assignee}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_repository_issues(self, owner, repo, payload=None):
+    def list_repository_issues(self, owner, repo, params=None, payload=None):
         """
         List repository issues
         https://docs.github.com/rest/reference/issues#list-repository-issues
@@ -116,10 +119,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_an_issue(self, owner, repo, payload=None):
+    def create_an_issue(self, owner, repo, params=None, payload=None):
         """
         Create an issue
         https://docs.github.com/rest/reference/issues#create-an-issue
@@ -131,10 +134,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def list_issue_comments_for_a_repository(self, owner, repo, payload=None):
+    def list_issue_comments_for_a_repository(self, owner, repo, params=None, payload=None):
         """
         List issue comments for a repository
         https://docs.github.com/rest/reference/issues#list-issue-comments-for-a-repository
@@ -150,10 +153,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_an_issue_comment(self, owner, repo, comment_id, payload=None):
+    def get_an_issue_comment(self, owner, repo, comment_id, params=None, payload=None):
         """
         Get an issue comment
         https://docs.github.com/rest/reference/issues#get-an-issue-comment
@@ -166,10 +169,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_an_issue_comment(self, owner, repo, comment_id, payload=None):
+    def update_an_issue_comment(self, owner, repo, comment_id, params=None, payload=None):
         """
         Update an issue comment
         https://docs.github.com/rest/reference/issues#update-an-issue-comment
@@ -182,10 +185,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def delete_an_issue_comment(self, owner, repo, comment_id, payload=None):
+    def delete_an_issue_comment(self, owner, repo, comment_id, params=None, payload=None):
         """
         Delete an issue comment
         https://docs.github.com/rest/reference/issues#delete-an-issue-comment
@@ -198,10 +201,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_issue_events_for_a_repository(self, owner, repo, payload=None):
+    def list_issue_events_for_a_repository(self, owner, repo, params=None, payload=None):
         """
         List issue events for a repository
         https://docs.github.com/rest/reference/issues#list-issue-events-for-a-repository
@@ -214,10 +217,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/events"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_an_issue_event(self, owner, repo, event_id, payload=None):
+    def get_an_issue_event(self, owner, repo, event_id, params=None, payload=None):
         """
         Get an issue event
         https://docs.github.com/rest/reference/issues#get-an-issue-event
@@ -230,10 +233,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/events/{event_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_an_issue(self, owner, repo, issue_number, payload=None):
+    def get_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Get an issue
         https://docs.github.com/rest/reference/issues#get-an-issue
@@ -246,10 +249,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_an_issue(self, owner, repo, issue_number, payload=None):
+    def update_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Update an issue
         https://docs.github.com/rest/reference/issues/#update-an-issue
@@ -262,10 +265,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def add_assignees_to_an_issue(self, owner, repo, issue_number, payload=None):
+    def add_assignees_to_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Add assignees to an issue
         https://docs.github.com/rest/reference/issues#add-assignees-to-an-issue
@@ -278,10 +281,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/assignees"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def remove_assignees_from_an_issue(self, owner, repo, issue_number, payload=None):
+    def remove_assignees_from_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Remove assignees from an issue
         https://docs.github.com/rest/reference/issues#remove-assignees-from-an-issue
@@ -294,10 +297,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/assignees"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_issue_comments(self, owner, repo, issue_number, payload=None):
+    def list_issue_comments(self, owner, repo, issue_number, params=None, payload=None):
         """
         List issue comments
         https://docs.github.com/rest/reference/issues#list-issue-comments
@@ -312,10 +315,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/comments"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_an_issue_comment(self, owner, repo, issue_number, payload=None):
+    def create_an_issue_comment(self, owner, repo, issue_number, params=None, payload=None):
         """
         Create an issue comment
         https://docs.github.com/rest/reference/issues#create-an-issue-comment
@@ -328,10 +331,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/comments"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def list_issue_events(self, owner, repo, issue_number, payload=None):
+    def list_issue_events(self, owner, repo, issue_number, params=None, payload=None):
         """
         List issue events
         https://docs.github.com/rest/reference/issues#list-issue-events
@@ -345,10 +348,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/events"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_labels_for_an_issue(self, owner, repo, issue_number, payload=None):
+    def list_labels_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         List labels for an issue
         https://docs.github.com/rest/reference/issues#list-labels-for-an-issue
@@ -362,10 +365,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def add_labels_to_an_issue(self, owner, repo, issue_number, payload=None):
+    def add_labels_to_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Add labels to an issue
         https://docs.github.com/rest/reference/issues#add-labels-to-an-issue
@@ -378,10 +381,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def set_labels_for_an_issue(self, owner, repo, issue_number, payload=None):
+    def set_labels_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Set labels for an issue
         https://docs.github.com/rest/reference/issues#set-labels-for-an-issue
@@ -394,10 +397,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def remove_all_labels_from_an_issue(self, owner, repo, issue_number, payload=None):
+    def remove_all_labels_from_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Remove all labels from an issue
         https://docs.github.com/rest/reference/issues#remove-all-labels-from-an-issue
@@ -410,11 +413,13 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def remove_a_label_from_an_issue(self, owner, repo, issue_number, name, payload=None):
-        # pylint: disable=too-many-arguments
+    def remove_a_label_from_an_issue(
+        self, owner, repo, issue_number, name, params=None, payload=None
+    ):
+
         """
         Remove a label from an issue
         https://docs.github.com/rest/reference/issues#remove-a-label-from-an-issue
@@ -428,10 +433,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels/{name}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def lock_an_issue(self, owner, repo, issue_number, payload=None):
+    def lock_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Lock an issue
         https://docs.github.com/rest/reference/issues#lock-an-issue
@@ -444,10 +449,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/lock"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def unlock_an_issue(self, owner, repo, issue_number, payload=None):
+    def unlock_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Unlock an issue
         https://docs.github.com/rest/reference/issues#unlock-an-issue
@@ -460,10 +465,12 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/lock"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_timeline_events_for_an_issue(self, owner, repo, issue_number, payload=None):
+    def list_timeline_events_for_an_issue(
+        self, owner, repo, issue_number, params=None, payload=None
+    ):
         """
         List timeline events for an issue
         https://docs.github.com/rest/reference/issues#list-timeline-events-for-an-issue
@@ -477,10 +484,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/timeline"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_labels_for_a_repository(self, owner, repo, payload=None):
+    def list_labels_for_a_repository(self, owner, repo, params=None, payload=None):
         """
         List labels for a repository
         https://docs.github.com/rest/reference/issues#list-labels-for-a-repository
@@ -493,10 +500,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_a_label(self, owner, repo, payload=None):
+    def create_a_label(self, owner, repo, params=None, payload=None):
         """
         Create a label
         https://docs.github.com/rest/reference/issues#create-a-label
@@ -508,10 +515,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_a_label(self, owner, repo, name, payload=None):
+    def get_a_label(self, owner, repo, name, params=None, payload=None):
         """
         Get a label
         https://docs.github.com/rest/reference/issues#get-a-label
@@ -524,10 +531,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_a_label(self, owner, repo, name, payload=None):
+    def update_a_label(self, owner, repo, name, params=None, payload=None):
         """
         Update a label
         https://docs.github.com/rest/reference/issues#update-a-label
@@ -540,10 +547,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def delete_a_label(self, owner, repo, name, payload=None):
+    def delete_a_label(self, owner, repo, name, params=None, payload=None):
         """
         Delete a label
         https://docs.github.com/rest/reference/issues#delete-a-label
@@ -556,10 +563,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_milestones(self, owner, repo, payload=None):
+    def list_milestones(self, owner, repo, params=None, payload=None):
         """
         List milestones
         https://docs.github.com/rest/reference/issues#list-milestones
@@ -575,10 +582,10 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_a_milestone(self, owner, repo, payload=None):
+    def create_a_milestone(self, owner, repo, params=None, payload=None):
         """
         Create a milestone
         https://docs.github.com/rest/reference/issues#create-a-milestone
@@ -590,10 +597,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_a_milestone(self, owner, repo, milestone_number, payload=None):
+    def get_a_milestone(self, owner, repo, milestone_number, params=None, payload=None):
         """
         Get a milestone
         https://docs.github.com/rest/reference/issues#get-a-milestone
@@ -606,10 +613,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_a_milestone(self, owner, repo, milestone_number, payload=None):
+    def update_a_milestone(self, owner, repo, milestone_number, params=None, payload=None):
         """
         Update a milestone
         https://docs.github.com/rest/reference/issues#update-a-milestone
@@ -622,10 +629,10 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def delete_a_milestone(self, owner, repo, milestone_number, payload=None):
+    def delete_a_milestone(self, owner, repo, milestone_number, params=None, payload=None):
         """
         Delete a milestone
         https://docs.github.com/rest/reference/issues#delete-a-milestone
@@ -638,10 +645,12 @@ class Issues:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_labels_for_issues_in_a_milestone(self, owner, repo, milestone_number, payload=None):
+    def list_labels_for_issues_in_a_milestone(
+        self, owner, repo, milestone_number, params=None, payload=None
+    ):
         """
         List labels for issues in a milestone
         https://docs.github.com/rest/reference/issues#list-labels-for-issues-in-a-milestone
@@ -655,10 +664,12 @@ class Issues:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}/labels"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_user_account_issues_assigned_to_the_authenticated_user(self, payload=None):
+    def list_user_account_issues_assigned_to_the_authenticated_user(
+        self, params=None, payload=None
+    ):
         """
         List user account issues assigned to the authenticated user
         https://docs.github.com/rest/reference/issues#list-user-account-issues-assigned-to-the-authenticated-user
@@ -676,5 +687,5 @@ class Issues:
          page
         """
         url = self._base_url + "/user/issues"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
