@@ -3,6 +3,7 @@ Interact with GitHub Orgs.
 """
 
 
+# pylint: disable=too-many-arguments
 class Orgs:
     # pylint: disable=too-many-public-methods
     """
@@ -16,7 +17,7 @@ class Orgs:
         self._base_url = client._base_url
         self._execute = client._execute
 
-    def list_organizations(self, payload=None):
+    def list_organizations(self, params=None, payload=None):
         """
         List organizations
         https://docs.github.com/rest/reference/orgs#list-organizations
@@ -28,10 +29,12 @@ class Orgs:
          per-page
         """
         url = self._base_url + "/organizations"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_custom_repository_roles_in_an_organization(self, organization_id, payload=None):
+    def list_custom_repository_roles_in_an_organization(
+        self, organization_id, params=None, payload=None
+    ):
         """
         List custom repository roles in an organization
         https://docs.github.com/rest/reference/orgs#list-custom-repository-roles-in-an-organization
@@ -42,10 +45,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/organizations/{organization_id}/custom_roles"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_an_organization(self, org, payload=None):
+    def get_an_organization(self, org, params=None, payload=None):
         """
         Get an organization
         https://docs.github.com/rest/reference/orgs#get-an-organization
@@ -56,10 +59,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_an_organization(self, org, payload=None):
+    def update_an_organization(self, org, params=None, payload=None):
         """
         Update an organization
         https://docs.github.com/rest/reference/orgs/#update-an-organization
@@ -70,10 +73,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def get_the_audit_log_for_an_organization(self, org, payload=None):
+    def get_the_audit_log_for_an_organization(self, org, params=None, payload=None):
         """
         Get the audit log for an organization
         https://docs.github.com/rest/reference/orgs#get-audit-log
@@ -89,10 +92,10 @@ class Orgs:
          per-page
         """
         url = self._base_url + f"/orgs/{org}/audit-log"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_users_blocked_by_an_organization(self, org, payload=None):
+    def list_users_blocked_by_an_organization(self, org, params=None, payload=None):
         """
         List users blocked by an organization
         https://docs.github.com/rest/reference/orgs#list-users-blocked-by-an-organization
@@ -103,10 +106,12 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/blocks"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def check_if_a_user_is_blocked_by_an_organization(self, org, username, payload=None):
+    def check_if_a_user_is_blocked_by_an_organization(
+        self, org, username, params=None, payload=None
+    ):
         """
         Check if a user is blocked by an organization
         https://docs.github.com/rest/reference/orgs#check-if-a-user-is-blocked-by-an-organization
@@ -118,10 +123,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/blocks/{username}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def block_a_user_from_an_organization(self, org, username, payload=None):
+    def block_a_user_from_an_organization(self, org, username, params=None, payload=None):
         """
         Block a user from an organization
         https://docs.github.com/rest/reference/orgs#block-a-user-from-an-organization
@@ -133,10 +138,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/blocks/{username}"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def unblock_a_user_from_an_organization(self, org, username, payload=None):
+    def unblock_a_user_from_an_organization(self, org, username, params=None, payload=None):
         """
         Unblock a user from an organization
         https://docs.github.com/rest/reference/orgs#unblock-a-user-from-an-organization
@@ -148,10 +153,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/blocks/{username}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_saml_sso_authorizations_for_an_organization(self, org, payload=None):
+    def list_saml_sso_authorizations_for_an_organization(self, org, params=None, payload=None):
         """
         List SAML SSO authorizations for an organization
         https://docs.github.com/rest/reference/orgs#list-saml-sso-authorizations-for-an-organization
@@ -164,10 +169,12 @@ class Orgs:
          login
         """
         url = self._base_url + f"/orgs/{org}/credential-authorizations"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def remove_a_saml_sso_authorization_for_an_organization(self, org, credential_id, payload=None):
+    def remove_a_saml_sso_authorization_for_an_organization(
+        self, org, credential_id, params=None, payload=None
+    ):
         """
         Remove a SAML SSO authorization for an organization
         https://docs.github.com/rest/reference/orgs#remove-a-saml-sso-authorization-for-an-organization
@@ -179,10 +186,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/credential-authorizations/{credential_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_failed_organization_invitations(self, org, payload=None):
+    def list_failed_organization_invitations(self, org, params=None, payload=None):
         """
         List failed organization invitations
         https://docs.github.com/rest/reference/orgs#list-failed-organization-invitations
@@ -194,10 +201,10 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/failed_invitations"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_organization_webhooks(self, org, payload=None):
+    def list_organization_webhooks(self, org, params=None, payload=None):
         """
         List organization webhooks
         https://docs.github.com/rest/reference/orgs#list-organization-webhooks
@@ -209,10 +216,10 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/hooks"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_an_organization_webhook(self, org, payload=None):
+    def create_an_organization_webhook(self, org, params=None, payload=None):
         """
         Create an organization webhook
         https://docs.github.com/rest/reference/orgs#create-an-organization-webhook
@@ -223,10 +230,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_an_organization_webhook(self, org, hook_id, payload=None):
+    def get_an_organization_webhook(self, org, hook_id, params=None, payload=None):
         """
         Get an organization webhook
         https://docs.github.com/rest/reference/orgs#get-an-organization-webhook
@@ -238,10 +245,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_an_organization_webhook(self, org, hook_id, payload=None):
+    def update_an_organization_webhook(self, org, hook_id, params=None, payload=None):
         """
         Update an organization webhook
         https://docs.github.com/rest/reference/orgs#update-an-organization-webhook
@@ -253,10 +260,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def delete_an_organization_webhook(self, org, hook_id, payload=None):
+    def delete_an_organization_webhook(self, org, hook_id, params=None, payload=None):
         """
         Delete an organization webhook
         https://docs.github.com/rest/reference/orgs#delete-an-organization-webhook
@@ -268,10 +275,12 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def get_a_webhook_configuration_for_an_organization(self, org, hook_id, payload=None):
+    def get_a_webhook_configuration_for_an_organization(
+        self, org, hook_id, params=None, payload=None
+    ):
         """
         Get a webhook configuration for an organization
         https://docs.github.com/rest/reference/orgs#get-a-webhook-configuration-for-an-organization
@@ -283,10 +292,12 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/config"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_a_webhook_configuration_for_an_organization(self, org, hook_id, payload=None):
+    def update_a_webhook_configuration_for_an_organization(
+        self, org, hook_id, params=None, payload=None
+    ):
         """
         Update a webhook configuration for an organization
         https://docs.github.com/rest/reference/orgs#update-a-webhook-configuration-for-an-organization
@@ -298,10 +309,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/config"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def list_deliveries_for_an_organization_webhook(self, org, hook_id, payload=None):
+    def list_deliveries_for_an_organization_webhook(self, org, hook_id, params=None, payload=None):
         """
         List deliveries for an organization webhook
         https://docs.github.com/rest/reference/orgs#list-deliveries-for-an-organization-webhook
@@ -314,11 +325,11 @@ class Orgs:
          cursor
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/deliveries"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def get_a_webhook_delivery_for_an_organization_webhook(
-        self, org, hook_id, delivery_id, payload=None
+        self, org, hook_id, delivery_id, params=None, payload=None
     ):
         """
         Get a webhook delivery for an organization webhook
@@ -332,11 +343,11 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/deliveries/{delivery_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def redeliver_a_delivery_for_an_organization_webhook(
-        self, org, hook_id, delivery_id, payload=None
+        self, org, hook_id, delivery_id, params=None, payload=None
     ):
         """
         Redeliver a delivery for an organization webhook
@@ -350,10 +361,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/deliveries/{delivery_id}/attempts"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def ping_an_organization_webhook(self, org, hook_id, payload=None):
+    def ping_an_organization_webhook(self, org, hook_id, params=None, payload=None):
         """
         Ping an organization webhook
         https://docs.github.com/rest/reference/orgs#ping-an-organization-webhook
@@ -365,10 +376,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/pings"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def list_app_installations_for_an_organization(self, org, payload=None):
+    def list_app_installations_for_an_organization(self, org, params=None, payload=None):
         """
         List app installations for an organization
         https://docs.github.com/rest/reference/orgs#list-app-installations-for-an-organization
@@ -380,10 +391,10 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/installations"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_pending_organization_invitations(self, org, payload=None):
+    def list_pending_organization_invitations(self, org, params=None, payload=None):
         """
         List pending organization invitations
         https://docs.github.com/rest/reference/orgs#list-pending-organization-invitations
@@ -395,10 +406,10 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/invitations"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_an_organization_invitation(self, org, payload=None):
+    def create_an_organization_invitation(self, org, params=None, payload=None):
         """
         Create an organization invitation
         https://docs.github.com/rest/reference/orgs#create-an-organization-invitation
@@ -409,10 +420,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/invitations"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def cancel_an_organization_invitation(self, org, invitation_id, payload=None):
+    def cancel_an_organization_invitation(self, org, invitation_id, params=None, payload=None):
         """
         Cancel an organization invitation
         https://docs.github.com/rest/reference/orgs#cancel-an-organization-invitation
@@ -424,10 +435,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/invitations/{invitation_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_organization_invitation_teams(self, org, invitation_id, payload=None):
+    def list_organization_invitation_teams(self, org, invitation_id, params=None, payload=None):
         """
         List organization invitation teams
         https://docs.github.com/rest/reference/orgs#list-organization-invitation-teams
@@ -440,10 +451,10 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/invitations/{invitation_id}/teams"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_organization_members(self, org, payload=None):
+    def list_organization_members(self, org, params=None, payload=None):
         """
         List organization members
         https://docs.github.com/rest/reference/orgs#list-organization-members
@@ -457,10 +468,10 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/members"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def check_organization_membership_for_a_user(self, org, username, payload=None):
+    def check_organization_membership_for_a_user(self, org, username, params=None, payload=None):
         """
         Check organization membership for a user
         https://docs.github.com/rest/reference/orgs#check-organization-membership-for-a-user
@@ -472,10 +483,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/members/{username}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def remove_an_organization_member(self, org, username, payload=None):
+    def remove_an_organization_member(self, org, username, params=None, payload=None):
         """
         Remove an organization member
         https://docs.github.com/rest/reference/orgs#remove-an-organization-member
@@ -487,10 +498,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/members/{username}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def get_organization_membership_for_a_user(self, org, username, payload=None):
+    def get_organization_membership_for_a_user(self, org, username, params=None, payload=None):
         """
         Get organization membership for a user
         https://docs.github.com/rest/reference/orgs#get-organization-membership-for-a-user
@@ -502,10 +513,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/memberships/{username}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def set_organization_membership_for_a_user(self, org, username, payload=None):
+    def set_organization_membership_for_a_user(self, org, username, params=None, payload=None):
         """
         Set organization membership for a user
         https://docs.github.com/rest/reference/orgs#set-organization-membership-for-a-user
@@ -517,10 +528,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/memberships/{username}"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def remove_organization_membership_for_a_user(self, org, username, payload=None):
+    def remove_organization_membership_for_a_user(self, org, username, params=None, payload=None):
         """
         Remove organization membership for a user
         https://docs.github.com/rest/reference/orgs#remove-organization-membership-for-a-user
@@ -532,10 +543,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/memberships/{username}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_outside_collaborators_for_an_organization(self, org, payload=None):
+    def list_outside_collaborators_for_an_organization(self, org, params=None, payload=None):
         """
         List outside collaborators for an organization
         https://docs.github.com/rest/reference/orgs#list-outside-collaborators-for-an-organization
@@ -548,10 +559,12 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/outside_collaborators"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def convert_an_organization_member_to_outside_collaborator(self, org, username, payload=None):
+    def convert_an_organization_member_to_outside_collaborator(
+        self, org, username, params=None, payload=None
+    ):
         """
         Convert an organization member to outside collaborator
         https://docs.github.com/rest/reference/orgs#convert-an-organization-member-to-outside-collaborator
@@ -563,10 +576,12 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/outside_collaborators/{username}"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def remove_outside_collaborator_from_an_organization(self, org, username, payload=None):
+    def remove_outside_collaborator_from_an_organization(
+        self, org, username, params=None, payload=None
+    ):
         """
         Remove outside collaborator from an organization
         https://docs.github.com/rest/reference/orgs#remove-outside-collaborator-from-an-organization
@@ -578,10 +593,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/outside_collaborators/{username}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_public_organization_members(self, org, payload=None):
+    def list_public_organization_members(self, org, params=None, payload=None):
         """
         List public organization members
         https://docs.github.com/rest/reference/orgs#list-public-organization-members
@@ -593,10 +608,12 @@ class Orgs:
          page
         """
         url = self._base_url + f"/orgs/{org}/public_members"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def check_public_organization_membership_for_a_user(self, org, username, payload=None):
+    def check_public_organization_membership_for_a_user(
+        self, org, username, params=None, payload=None
+    ):
         """
         Check public organization membership for a user
         https://docs.github.com/rest/reference/orgs#check-public-organization-membership-for-a-user
@@ -608,11 +625,11 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/public_members/{username}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def set_public_organization_membership_for_the_authenticated_user(
-        self, org, username, payload=None
+        self, org, username, params=None, payload=None
     ):
         """
         Set public organization membership for the authenticated user
@@ -625,11 +642,11 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/public_members/{username}"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def remove_public_organization_membership_for_the_authenticated_user(
-        self, org, username, payload=None
+        self, org, username, params=None, payload=None
     ):
         """
         Remove public organization membership for the authenticated user
@@ -642,10 +659,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/orgs/{org}/public_members/{username}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_organization_memberships_for_the_authenticated_user(self, payload=None):
+    def list_organization_memberships_for_the_authenticated_user(self, params=None, payload=None):
         """
         List organization memberships for the authenticated user
         https://docs.github.com/rest/reference/orgs#list-organization-memberships-for-the-authenticated-user
@@ -658,10 +675,12 @@ class Orgs:
          page
         """
         url = self._base_url + "/user/memberships/orgs"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_an_organization_membership_for_the_authenticated_user(self, org, payload=None):
+    def get_an_organization_membership_for_the_authenticated_user(
+        self, org, params=None, payload=None
+    ):
         """
         Get an organization membership for the authenticated user
         https://docs.github.com/rest/reference/orgs#get-an-organization-membership-for-the-authenticated-user
@@ -672,10 +691,12 @@ class Orgs:
 
         """
         url = self._base_url + f"/user/memberships/orgs/{org}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_an_organization_membership_for_the_authenticated_user(self, org, payload=None):
+    def update_an_organization_membership_for_the_authenticated_user(
+        self, org, params=None, payload=None
+    ):
         """
         Update an organization membership for the authenticated user
         https://docs.github.com/rest/reference/orgs#update-an-organization-membership-for-the-authenticated-user
@@ -686,10 +707,10 @@ class Orgs:
 
         """
         url = self._base_url + f"/user/memberships/orgs/{org}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def list_organizations_for_the_authenticated_user(self, payload=None):
+    def list_organizations_for_the_authenticated_user(self, params=None, payload=None):
         """
         List organizations for the authenticated user
         https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user
@@ -701,10 +722,10 @@ class Orgs:
          page
         """
         url = self._base_url + "/user/orgs"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_organizations_for_a_user(self, username, payload=None):
+    def list_organizations_for_a_user(self, username, params=None, payload=None):
         """
         List organizations for a user
         https://docs.github.com/rest/reference/orgs#list-organizations-for-a-user
@@ -716,5 +737,5 @@ class Orgs:
          page
         """
         url = self._base_url + f"/users/{username}/orgs"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
